@@ -199,13 +199,14 @@ class User(FirebaseCollectionBase):
         if type(user) is str:
             user = {"uid": user, "id": user}
         (cls_object, keys, data_args) = init_class_kwargs(self, user, USER_FIELDS, UserFieldProps, USERS_COLLECTION, ['id','uid'], **kwargs)
+
         super().__init__(**data_args);
-        # print('cls_object', cls_object)
-        # print('keys', keys)
-        # print('data_args', data_args)
         if len(keys) == 0:
             if 'fields' in data_args:
                 keys = data_args['fields']
+        print('cls_object', cls_object)
+        print('keys', keys)
+        # print('data_args', data_args)
         for key in keys:
             if key in cls_object:
                 if key == "phoneInfo":
@@ -243,11 +244,13 @@ class User(FirebaseCollectionBase):
     
     def to_dict(self, fields=None):
         # base = super().to_dict(fields)
-        # print('base', base['ages'])
-        telephone = self.telephone;
+        # print('base', base['ages']);
+        telephone = getattr(self, 'telephone', None);
         postal = self.postalCode;
         provider = self.provider;
         phoneInfo = None;
+        firstName = None;
+        lastName = None;
         if self.phoneInfo is not None:
             phoneInfo = self.phoneInfo.to_dict();
         if bool(provider) is False:
@@ -259,13 +262,17 @@ class User(FirebaseCollectionBase):
         if bool(postal) is False and bool(self.postal) is True:
             postal = self.postal
         
+        if getattr(self, 'firstName', None) is not None:
+            firstName = self.firstName
+        if getattr(self, 'lastName', None) is not None:
+            lastName = self.lastName
         values = {
             "uid": self.uid,
             "email": self.email,
             "password": self.password,
             "displayName": self.displayName,
-            "firstName": self.first_name,
-            "lastName": self.last_name,
+            "firstName": firstName,
+            "lastName": lastName,
             "provider": provider,
             "entrepriseName": self.entrepriseName,
             "entrepriseUrl": self.entrepriseUrl,
@@ -297,7 +304,8 @@ class User(FirebaseCollectionBase):
             return None;
         # print('user found', doc.to_dict())
         d = pydash.pick(doc.to_dict(), USER_FIELDS)
-        return User.from_dict(user=d, db=self.db, collection_name=self.collection_name);
+        new_user = User.from_dict(user=d, db=self.db, collection_name=self.collection_name)
+        return new_user;
 
     def query(self, query_params: list, first=False, limit=None):
         result = [];
