@@ -80,8 +80,8 @@ class UserFields(BaseFieldsClass):
     displayName = 'displayName';
     firstName = 'firstName';
     lastName = 'lastName';
-    first_name = 'lastName';
-    last_name = 'last_name';
+    first_name = 'firsttName';
+    last_name = 'lastName';
     provider = 'provider';
     entrepriseName = 'entrepriseName';
     entrepriseUrl = 'entrepriseUrl';
@@ -170,6 +170,24 @@ UserFieldProps = {
         "default_value": "",
         "pickable": True,
     },
+    UserFields.first_name: {
+        "type": str,
+        "required": False,
+        "mutable": True,
+        "editable": True,
+        "interactive": True,
+        "default_value": "",
+        "pickable": True,
+    },
+    UserFields.last_name: {
+        "type": str,
+        "required": False,
+        "mutable": True,
+        "editable": True,
+        "interactive": True,
+        "default_value": "",
+        "pickable": True,
+    },
     UserFields.displayName: {
         "type": str,
         "required": False,
